# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-MRO-Compat
Version:	0.15
Release:	6.%{__distinit}%{__distvers}
Summary:	Mro::* interface compatibility for Perls < 5.9.5
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/MRO-Compat
Source0:	https://cpan.metacpan.org/authors/id/H/HA/HAARG/MRO-Compat-%{version}.tar.gz
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test
BuildRequires:	perl(Test::More) >= 0.47
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
The "mro" namespace provides several utilities for dealing with method
resolution order and method caching in general in Perl 5.9.5 and higher.
This module provides those interfaces for earlier versions of Perl (back
to 5.6.0 anyways).

It is a harmless no-op to use this module on 5.9.5+. That is to say,
code which properly uses MRO::Compat will work unmodified on both older
Perls and 5.9.5+.

If you're writing a piece of software that would like to use the parts
of 5.9.5+'s mro:: interfaces that are supported here, and you want
compatibility with older Perls, this is the module for you.

%prep
%setup -q -n MRO-Compat-%{version}

# Fix script interpreter
perl -pi -e 's|^#!./perl|#!/usr/bin/perl|' t/15pkg_gen.t

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README t/
%{perl_vendorlib}/MRO/
%{_mandir}/man3/MRO::Compat.3*

%changelog
* Wed Mar 22 2023 Paul Howarth <paul@city-fan.org> - 0.15-6
- Use SPDX-format license tag

* Sat Jan  8 2022 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15
  - Optimize pure perl DFS inheritance calculation on perl 5.8
  - Fix function prototypes to match core functions
  - Pod formatting fix
- Package new LICENSE file

* Sun Jun  2 2019 Paul Howarth <paul@city-fan.org> - 0.13-8
- Perl 5.30 rebuild

* Thu Apr 26 2018 Paul Howarth <paul@city-fan.org> - 0.13-4
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop dependencies on Class::C3 for Perl < 5.9.5

* Wed Mar 29 2017 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13
  - Don't run pod tests on user installs
  - Stop using Module::Install to fix installation when @INC doesn't have the
    current directory (CPAN RT#119016)
  - Repository migrated to the github moose organization
- This release by HAARG → update source URL

* Thu Sep  8 2016 Paul Howarth <paul@city-fan.org> - 0.12-12
- Fix FTBFS when perl is not in the minimal buildroot
- BR: perl-generators where available
- Simplify find command using -delete

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 0.12-6
- Drop %%defattr, redundant since rpm 4.4

* Wed Dec  5 2012 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12
  - Bump Class::C3 dependency on 5.8, which in turn will automatically install
    Class::C3::XS if possible
  - Fix nonfunctional SYNOPSIS (CPAN RT#78325)
- This release by BOBTFISH → update source URL
- BR: perl(File::Spec) for bundled Module::Install

* Fri Jun 29 2012 Paul Howarth <paul@city-fan.org> - 0.11-10
- BR: perl(Cwd) and perl(File::Path) for bundled Module::Install
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jan 26 2012 Paul Howarth <paul@city-fan.org> - 0.11-9
- Only BR:/R: Class::C3/Class::C3::XS with perl < 5.9.5

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 0.11-7
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.11-6
- Rebuild for perl 5.12.1 in Rawhide

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> - 0.11-5
- Fix dist tag for RHEL-6 Beta

* Wed Feb 17 2010 Paul Howarth <paul@city-fan.org> - 0.11-4
- Dist tag for Rawhide no longer needs special-casing

* Tue Aug 11 2009 Paul Howarth <paul@city-fan.org> - 0.11-3
- Import from Fedora
- Remove version numbers from module dependencies

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jun 02 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.11-1
- Auto-update to 0.11 (by cpan-spec-update 0.01)
- Altered br on perl(ExtUtils::MakeMaker) (0 => 6.42)
- Altered br on perl(Class::C3) (0.19 => 0.20)

* Thu Apr 02 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.10-1
- Update to 0.10

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.09-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Jun 28 2008 Chris Weyl <cweyl@alumni.drew.edu> - 0.09
- Update to 0.09

* Wed May 28 2008 Chris Weyl <cweyl@alumni.drew.edu> - 0.07-1
- Update to 0.07

* Wed Mar 05 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.05-6
- Rebuild for new perl

* Thu Dec 06 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.05-5
- Bump

* Wed Dec 05 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.05-4
- Update INstall -> install

* Wed Dec 05 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.05-3
- Add Test::Pod deps

* Tue Dec 04 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.05-2
- Make Class::C3 dep explicit

* Tue Sep 18 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.05-1
- Specfile autogenerated by cpanspec 1.71
